==> mmoo_base-1.2.0%2B1.tar.gz: lib/ui/text_widget.dart <==
import 'package:flutter/material.dart';

///带图标Icon的文本，可调节
class TextWidget extends StatefulWidget {
  final String? iconText;
  final iconData;
  final TextStyle textStyle;
  final double iconPadding;
  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final CrossAxisAlignment crossAxisAlignment;
  final double? maxWidth;
  final bool textExpanded;
  final bool right;
  final Decoration? decoration;
  final EdgeInsetsGeometry? padding;
  final EdgeInsetsGeometry? margin;
  final TextAlign? textAlign;
  final int? maxLines;
  final double? height;

  TextWidget(
    this.iconText,
    this.textStyle, {
    Key? key,
    this.iconData,
    this.iconPadding = 0.0,
    this.mainAxisAlignment = MainAxisAlignment.start,
    this.mainAxisSize = MainAxisSize.max,
    this.crossAxisAlignment = CrossAxisAlignment.center,
    this.maxWidth,
    this.right = false,
    this.decoration,
    this.padding,
    this.margin,
    this.textExpanded = false,
    this.maxLines = 1,
    this.textAlign,
    this.height,
  }) : super(key: key);

  @override
  TextWidgetState createState() => TextWidgetState();
}

class TextWidgetState extends State<TextWidget> {
  String? iconText;

  @override
  void initState() {
    super.initState();
    iconText = widget.iconText;
  }

  void onSetState(String text) {
    this.iconText = text;
    setState(() {});
  }

  @override
  void didUpdateWidget(TextWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.iconText?.isEmpty == false && iconText != widget.iconText)
      iconText = widget.iconText;
  }

  @override
  Widget build(BuildContext context) {
    Widget showText = (widget.maxWidth == null)
        ? Container(
            child: Text(iconText ?? '',
                style: widget.textStyle
                    .merge(TextStyle(textBaseline: TextBaseline.alphabetic)),
                textAlign: widget.textAlign,
                overflow:
                    widget.maxLines == null ? null : TextOverflow.ellipsis,
                maxLines: widget.maxLines))
        : Container(
            constraints: BoxConstraints(maxWidth: widget.maxWidth!),
            child:

                ///显示数量文本
                Text(iconText ?? '',
                    style: widget.textStyle.merge(
                        TextStyle(textBaseline: TextBaseline.alphabetic)),
                    textAlign: widget.textAlign,
                    overflow:
                        widget.maxLines == null ? null : TextOverflow.ellipsis,
                    maxLines: widget.maxLines));
    if (widget.iconData == null) {
      return Container(
        decoration: widget.decoration,
        padding: widget.padding,
        margin: widget.margin,
        height: widget.height,
        child: Row(
          textBaseline: TextBaseline.alphabetic,
          mainAxisAlignment: widget.mainAxisAlignment,
          mainAxisSize: widget.mainAxisSize,
          crossAxisAlignment: widget.crossAxisAlignment,
          children: <Widget>[
            widget.textExpanded ? Expanded(child: showText) : showText
          ],
        ),
      );
    } else {
      return Container(
        decoration: widget.decoration,
        padding: widget.padding,
        margin: widget.margin,
        height: widget.height,
        child: Row(
          textBaseline: TextBaseline.alphabetic,
          mainAxisAlignment: widget.mainAxisAlignment,
          mainAxisSize: widget.mainAxisSize,
          crossAxisAlignment: widget.crossAxisAlignment,
          children: (widget.right
              ? <Widget>[
                  widget.textExpanded ? Expanded(child: showText) : showText,
                  Padding(padding: EdgeInsets.all(widget.iconPadding)),
                  widget.iconData
                ]
              : <Widget>[
                  widget.iconData,
                  Padding(padding: EdgeInsets.all(widget.iconPadding)),
                  widget.textExpanded ? Expanded(child: showText) : showText
                ]),
        ),
      );
    }
  }
}

==> mmoo_base-1.3.0%2B1.tar.gz: lib/ui/text_widget.dart <==
import 'package:flutter/material.dart';

///带图标Icon的文本，可调节
class TextWidget extends StatefulWidget {
  final String? iconText;
  final dynamic iconData;
  final TextStyle textStyle;
  final double iconPadding;
  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final CrossAxisAlignment crossAxisAlignment;
  final double? maxWidth;
  final bool textExpanded;
  final bool right;
  final Decoration? decoration;
  final EdgeInsetsGeometry? padding;
  final EdgeInsetsGeometry? margin;
  final TextAlign? textAlign;
  final int? maxLines;
  final double? height;

  const TextWidget(
    this.iconText,
    this.textStyle, {
    Key? key,
    this.iconData,
    this.iconPadding = 0.0,
    this.mainAxisAlignment = MainAxisAlignment.start,
    this.mainAxisSize = MainAxisSize.max,
    this.crossAxisAlignment = CrossAxisAlignment.center,
    this.maxWidth,
    this.right = false,
    this.decoration,
    this.padding,
    this.margin,
    this.textExpanded = false,
    this.maxLines = 1,
    this.textAlign,
    this.height,
  }) : super(key: key);

  @override
  TextWidgetState createState() => TextWidgetState();
}

class TextWidgetState extends State<TextWidget> {
  String? iconText;

  @override
  void initState() {
    super.initState();
    iconText = widget.iconText;
  }

  void onSetState(String text) {
    iconText = text;
    setState(() {});
  }

  @override
  void didUpdateWidget(TextWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.iconText?.isEmpty == false && iconText != widget.iconText) {
      iconText = widget.iconText;
    }
  }

  @override
  Widget build(BuildContext context) {
    Widget showText = (widget.maxWidth == null)
        ? Text(iconText ?? '',
            style: widget.textStyle
                .merge(const TextStyle(textBaseline: TextBaseline.alphabetic)),
            textAlign: widget.textAlign,
            overflow: widget.maxLines == null ? null : TextOverflow.ellipsis,
            maxLines: widget.maxLines)
        : Container(
            constraints: BoxConstraints(maxWidth: widget.maxWidth!),
            child:

                ///显示数量文本
                Text(iconText ?? '',
                    style: widget.textStyle.merge(
                        const TextStyle(textBaseline: TextBaseline.alphabetic)),
                    textAlign: widget.textAlign,
                    overflow:
                        widget.maxLines == null ? null : TextOverflow.ellipsis,
                    maxLines: widget.maxLines));
    if (widget.iconData == null) {
      return Container(
        decoration: widget.decoration,
        padding: widget.padding,
        margin: widget.margin,
        height: widget.height,
        child: Row(
          textBaseline: TextBaseline.alphabetic,
          mainAxisAlignment: widget.mainAxisAlignment,
          mainAxisSize: widget.mainAxisSize,
          crossAxisAlignment: widget.crossAxisAlignment,
          children: <Widget>[
            widget.textExpanded ? Expanded(child: showText) : showText
          ],
        ),
      );
    } else {
      return Container(
        decoration: widget.decoration,
        padding: widget.padding,
        margin: widget.margin,
        height: widget.height,
        child: Row(
          textBaseline: TextBaseline.alphabetic,
          mainAxisAlignment: widget.mainAxisAlignment,
          mainAxisSize: widget.mainAxisSize,
          crossAxisAlignment: widget.crossAxisAlignment,
          children: (widget.right
              ? <Widget>[
                  widget.textExpanded ? Expanded(child: showText) : showText,
                  Padding(padding: EdgeInsets.all(widget.iconPadding)),
                  widget.iconData
                ]
              : <Widget>[
                  widget.iconData,
                  Padding(padding: EdgeInsets.all(widget.iconPadding)),
                  widget.textExpanded ? Expanded(child: showText) : showText
                ]),
        ),
      );
    }
  }
}
